import os
import pathlib
import subprocess
import sys

from hatchling.builders.hooks.plugin.interface import BuildHookInterface


class CustomBuildHook(BuildHookInterface):
    def initialize(self, _version, _build_data):
        try:
            os.chdir(pathlib.Path("pyloggrid/LogGrid"))
            if sys.platform == "win32":
                subprocess.check_call(["make", "clean", "-f", "Makefile.windows"])
                subprocess.check_call(["make", "-f", "Makefile.windows"])
            else:
                subprocess.check_call(["make", "clean"])
                subprocess.check_call(["make"])

            print("Module compilation completed successfully.")
        except Exception as e:
            print(f"Error compiling modules: {str(e)}")
            raise Exception("Error compiling modules.")



"""Cython settings for linux"""

import os

import numpy as np
from Cython.Build import cythonize
from setuptools import Extension, setup

os.environ["CC"] = "clang"
os.environ["CXX"] = "clang -shared"

ext_modules = [
    Extension(
        "compute_convolution_kernel",
        ["compute_convolution_kernel.pyx"],
        extra_compile_args=[
            "-fopenmp",
            "-march=native",
            "-c",
            "-g",
            "-Wextra",
            "-march=native",
            "-ffast-math",
            "-funroll-loops",
            "-fno-stack-protector",
        ],
        extra_link_args=["-fopenmp"],
    )
]

setup(
    ext_modules=cythonize(ext_modules, annotate=True),
    include_dirs=[np.get_include()],
    name="log-grid",
    author="A. Barral",
)
